# Change Log

## [0.1.1] - (2024-06-27)

### Docs

- Add documentation


## [0.1.0] - (2024-06-27)

Initial release

[0.1.0]: https://github.com/py-art/arfi-settings/releases/tag/0.1.0
[0.1.1]: https://github.com/py-art/arfi-settings/releases/tag/0.1.1
